@@ -12,7 +12,7 @@ use App::Ack::Filter::Collection ();
 use App::Ack::Filter::Default ();
 use App::Ack::Filter::IsPath ();
 use File::Spec 3.00 ();
-use Getopt::Long 2.38 ();
+use Getopt::Long 2.39 ();
 use Text::ParseWords 3.1 ();
 
 sub opt_parser {
@@ -234,8 +234,7 @@ sub get_arg_spec {
     * Add your option to t/Util.pm#get_expected_options
     * Add your option's description and aliases to dev/generate-completion-scripts.pl
     * Go through the list of options already available, and consider
-      whether your new option can be considered mutually exclusive
-      with another option.
+      whether your new option can be considered mutex with another option.
 
 =end Adding-Options
 
@@ -263,7 +262,7 @@ sub get_arg_spec {
         }
 
         return;
-    };
+    }
 
     return {
         1                   => sub { $opt->{1} = $opt->{m} = 1 },
@@ -611,7 +610,7 @@ sub process_args {
 
     my $type_specs = _process_filetypes(\%opt, $arg_sources);
 
-    _check_for_mutually_exclusive_options( $type_specs );
+    _check_for_mutex_options( $type_specs );
 
     _process_other(\%opt, $type_specs, $arg_sources);
     while ( @{$arg_sources} ) {
@@ -722,8 +721,8 @@ sub read_rcfile {
 }
 
 
-# Verifies no mutually-exclusive options were passed.  Dies if they were.
-sub _check_for_mutually_exclusive_options {
+# Verifies no mutex options were passed.  Dies if they were.
+sub _check_for_mutex_options {
     my $type_specs = shift;
 
     my $mutex = mutex_options();
@@ -738,7 +737,7 @@ sub _check_for_mutually_exclusive_options {
             if ( $mutex->{$i}{$j} ) {
                 my $x = $raw->[ $used->{$i} ];
                 my $y = $raw->[ $used->{$j} ];
-                App::Ack::die( "Options '$x' and '$y' are mutually exclusive" );
+                App::Ack::die( "Options '$x' and '$y' can't be used together." );
             }
         }
     }
@@ -850,7 +849,7 @@ we store it in C<@raw> as "--proximate".
 
 
 sub mutex_options {
-    # This list is machine-generated by crank-mutex.  Do not modify it by hand.
+    # This list is machine-generated by dev/crank-mutex.  Do not modify it by hand.
 
     return {
         1 => {
@@ -965,6 +964,7 @@ sub mutex_options {
             c => 1,
             column => 1,
             f => 1,
+            'files-from' => 1,
             g => 1,
             group => 1,
             h => 1,
@@ -980,6 +980,11 @@ sub mutex_options {
             v => 1,
             x => 1,
         },
+        'files-from' => {
+            f => 1,
+            g => 1,
+            x => 1,
+        },
         g => {
             A => 1,
             B => 1,
@@ -990,6 +995,7 @@ sub mutex_options {
             c => 1,
             column => 1,
             f => 1,
+            'files-from' => 1,
             g => 1,
             group => 1,
             h => 1,
@@ -1076,6 +1082,7 @@ sub mutex_options {
             p => 1,
             passthru => 1,
             'show-types' => 1,
+            v => 1,
         },
         output => {
             A => 1,
@@ -1093,6 +1100,7 @@ sub mutex_options {
             passthru => 1,
             'show-types' => 1,
             u => 1,
+            v => 1,
         },
         p => {
             A => 1,
@@ -1123,6 +1131,7 @@ sub mutex_options {
             o => 1,
             output => 1,
             p => 1,
+            v => 1,
         },
         'show-types' => {
             L => 1,
@@ -1139,6 +1148,9 @@ sub mutex_options {
             L => 1,
             column => 1,
             f => 1,
+            o => 1,
+            output => 1,
+            passthru => 1,
         },
         'with-filename' => {
             L => 1,
@@ -1146,9 +1158,11 @@ sub mutex_options {
         },
         x => {
             f => 1,
+            'files-from' => 1,
             g => 1,
         },
     };
+
 }   # End of mutex_options()
 
 
